@@ -1,7 +1,4 @@
-import click
-from beet import Context
-
-from .main import run_weld, print_pack_name
+from .main import print_pack_name, run_weld
 from .merge_policies import beet_default, setup
 
 __all__ = [
